==> easyleetcode-2.0.2.tar.gz: easyleetcode-2.0.2/README.md <==
# easyleetcode

- A simple Python leetcode study and running online tool
- Just need your computer to run the python environment


use it, from pip：`pip install easyleetcode`

then , only 2 line code , in any location:
```python
from easyleetcode import run

run()
# or run(host="127.0.0.1", port=8080)
```

or use it, from source code : **clone source** then:
- 1.pip install these package >> `['uvicorn', 'fastapi', 'pydantic', 'aiofiles', 'jinja2']`
- 2.run python script : `easyleetcode/web/main.py`



---

## Introduction


- Hello Python 程序员//Hello Python programmer
- 你可以用它//You can use it
- 成为轻松刷Leetcode的大神//Become the God of leetcode
- 你可以用它//You can use it
- 在线运行或添加你的任意Python代码//Run or add your arbitrary Python code online
- 你可以用它//You can use it
- 给你的任意Python代码做Markdwon笔记//Take markdwon notes for any Python code you want
- 它运行非常流畅//It runs very smoothly
- 你可以把它当做代码笔记包 // You can use it as leetcode study package


---

## index view
![](imgs/index.png)


## code list view
all code list , you can add new code or 

edit code or note markdown 
or see video (if exist, tell me)

or select contain keyword code use button 'Find'
![](imgs/code_view.png)

---

## select code
only see contain 'Sum' code
![](imgs/code_view_find.png)


---

## code show view
code detail view

you can run & debug & study & add code & note Markdown

you can edit you python code & run you code online !
![](imgs/code_show.png)

---

## code markdown note view
code's markdown note 

you can click Edit Button to Edit you note
![](imgs/code_md.png)


---

## code markdown note edit view
code's markdown note can easy online edit, and 

you can click Save Button to Save you Edited note

left textarea to edit Markdown, right textarea show markdown's result view
![](https://img-blog.csdnimg.cn/20200618094528702.png?x-oss-process=image/watermark,type_ZmFuZ3poZW5naGVpdGk,shadow_10,text_aHR0cHM6Ly9ibG9nLmNzZG4ubmV0L2ppYW5nNDI1Nzc2MDI0,size_16,color_FFFFFF,t_70)

==> easyleetcode-2.0.3.tar.gz: easyleetcode-2.0.3/README.md <==
# easyleetcode

- A simple Python leetcode study and running online tool
- Just need your computer to run the python environment


use it, from pip：`pip install easyleetcode`

then , only 2 line code , in any location:
```python
from easyleetcode import run

run()
# or run(host="127.0.0.1", port=8080)
```

or use it, from source code : **clone source** then:
- 1.pip install these package >> `['uvicorn', 'fastapi', 'pydantic', 'aiofiles', 'jinja2']`
- 2.run python script : `easyleetcode/web/main.py`



---

## Introduction


- Hello Python 程序员//Hello Python programmer
- 你可以用它//You can use it
- 成为轻松刷Leetcode的大神//Become the God of leetcode
- 你可以用它//You can use it
- 在线运行或添加你的任意Python代码//Run or add your arbitrary Python code online
- 你可以用它//You can use it
- 给你的任意Python代码做Markdwon笔记//Take markdwon notes for any Python code you want
- 它运行非常流畅//It runs very smoothly
- 你可以把它当做代码笔记包 // You can use it as leetcode study package


---

## index view
![](https://img-blog.csdnimg.cn/20200620202301906.png?x-oss-process=image/watermark,type_ZmFuZ3poZW5naGVpdGk,shadow_10,text_aHR0cHM6Ly9ibG9nLmNzZG4ubmV0L2ppYW5nNDI1Nzc2MDI0,size_16,color_FFFFFF,t_70)


## code list view
all code list , you can add new code or 

edit code or note markdown 
or see video (if exist, tell me)

or select contain keyword code use button 'Find'
![](imgs/code_view.png)

---

## select code
only see contain 'Sum' code
![](https://img-blog.csdnimg.cn/20200620202319563.png?x-oss-process=image/watermark,type_ZmFuZ3poZW5naGVpdGk,shadow_10,text_aHR0cHM6Ly9ibG9nLmNzZG4ubmV0L2ppYW5nNDI1Nzc2MDI0,size_16,color_FFFFFF,t_70)


---

## code show view
code detail view

you can run & debug & study & add code & note Markdown

you can edit you python code & run you code online !
![](https://img-blog.csdnimg.cn/20200620202344743.png?x-oss-process=image/watermark,type_ZmFuZ3poZW5naGVpdGk,shadow_10,text_aHR0cHM6Ly9ibG9nLmNzZG4ubmV0L2ppYW5nNDI1Nzc2MDI0,size_16,color_FFFFFF,t_70)

---

## code markdown note view
code's markdown note 

you can click Edit Button to Edit you note
![](https://img-blog.csdnimg.cn/20200620202407743.png?x-oss-process=image/watermark,type_ZmFuZ3poZW5naGVpdGk,shadow_10,text_aHR0cHM6Ly9ibG9nLmNzZG4ubmV0L2ppYW5nNDI1Nzc2MDI0,size_16,color_FFFFFF,t_70)


---

## code markdown note edit view
code's markdown note can easy online edit, and 

you can click Save Button to Save you Edited note

left textarea to edit Markdown, right textarea show markdown's result view
![](https://img-blog.csdnimg.cn/20200618094528702.png?x-oss-process=image/watermark,type_ZmFuZ3poZW5naGVpdGk,shadow_10,text_aHR0cHM6Ly9ibG9nLmNzZG4ubmV0L2ppYW5nNDI1Nzc2MDI0,size_16,color_FFFFFF,t_70)
